@@ -149,3 +149,59 @@ def knight_move(self, game, src):
         i += 1
 
     return new_result
+
+def bishop_move(self, game, src):
+    """ Validates bishop move """
+    x = src[0]
+    y = src[1]
+    result = []
+
+    loop_condition = (lambda i: i < 8) if self.color == 'white' else (lambda i: i >= 0)
+    reverse_loop_condition = (lambda i: i < 8) if self.color == 'black' else (lambda i: i >= 0)
+    counter_eval = +1 if self.color == 'white' else -1
+    reverse_counter_eval = -counter_eval
+
+    loops = [
+        [loop_condition, counter_eval],
+        [reverse_loop_condition, reverse_counter_eval]
+    ]
+
+    for loop in loops:
+        i = x
+        j = y
+        while loop[0](i) and loop[0](j):
+            if i != x and j != y:
+                try:
+                    if game.board[i][j] is not None:
+                        if game.board[i][j].color != self.color:
+                            result.append([i, j])
+                        break
+                except:
+                    break
+                result.append([i, j])
+            i += loop[1]
+            j += loop[1]
+
+    for loop in loops:
+        i = x
+        j = y
+        while loop[0](i) and loop[0](j):
+            if i != x and j != y:
+                try:
+                    if game.board[i][j] is not None:
+                        if game.board[i][j].color != self.color:
+                            result.append([i, j])
+                        break
+                except:
+                    break
+                result.append([i, j])
+            i += -loop[1]
+            j += loop[1]
+
+    new_result = []
+    for item in result:
+        if item[0] >= 0 and item[1] >= 0:
+            if item != src:
+                new_result.append(item)
+
+    return new_result
