@@ -13,7 +13,7 @@ try:
 except ImportError:
     import moves
 
-VERSION = '0.0.10'
+VERSION = '0.0.13'
 
 class Ansi:
     """ The terminal ansi chars """
@@ -77,11 +77,13 @@ class Piece:
         elif self.name == Piece.ROCK:
             result = moves.rock_move(self, game, src)
         elif self.name == Piece.QUEEN:
-            result = [*moves.rock_move(self, game, src)]
+            result = [*moves.rock_move(self, game, src), *moves.bishop_move(self, game, src)]
         elif self.name == Piece.KING:
             result = moves.king_move(self, game, src)
         elif self.name == Piece.KNIGHT:
             result = moves.knight_move(self, game, src)
+        elif self.name == Piece.BISHOP:
+            result = moves.bishop_move(self, game, src)
         else:
             result = []
         if return_locations:
@@ -119,6 +121,13 @@ class Game:
         self.white_player = 'White'
         self.black_player = 'Black'
 
+        # game status
+        self.is_end = False
+        self.winner = None
+
+        # currently which team is check
+        self.current_check = None
+
         # initialize the board
         self.board = []
         for i in range(8):
@@ -164,6 +173,33 @@ class Game:
         """
         self.turn = 'black' if self.turn == 'white' else 'white'
 
+        self.handle_check()
+
+    def handle_check(self):
+        """ Handle the check and checkmate """
+        for color in ('white', 'black'):
+            for i in range(0, len(self.board)):
+                for j in range(0, len(self.board[i])):
+                    if self.board[i][j] is not None:
+                        if self.board[i][j].color == color:
+                            for item in self.board[i][j].allowed_moves(self, [i, j], [0, 0], return_locations=True):
+                                if self.board[item[0]][item[1]] is not None:
+                                    if self.board[item[0]][item[1]].color != color:
+                                        if self.board[item[0]][item[1]].name == Piece.KING:
+                                            if color == self.turn:
+                                                self.checkmate()
+                                            else:
+                                                self.check(self.board[item[0]][item[1]].color)
+
+    def checkmate(self):
+        """ Changes game status to the checkmate """
+        self.is_end = True
+        self.winner = self.turn
+
+    def check(self, color):
+        """ Sets check status for a color """
+        self.current_check = color
+
     def move(self, src, dst):
         """ Moves src to dst """
         dst_p = copy.deepcopy(self.board[dst[0]][dst[1]])
@@ -340,8 +376,8 @@ class Game:
         output = ''
 
         # render the player names
-        white_player = 'B. ' + self.white_player
-        black_player = 'W. ' + self.black_player
+        white_player = 'B. ' + self.white_player + (' (Check!)' if 'white' == self.current_check else '')
+        black_player = 'W. ' + self.black_player + (' (Check!)' if 'black' == self.current_check else '')
         white_space_len = (len(self.ROW_SEPARATOR) - (len(white_player)+len(black_player))) - 2
         white_space_len = int(white_space_len/2)
         player_names = Ansi.CYAN + white_player + Ansi.RESET + (' ' * white_space_len) + 'Vs' + (' ' * white_space_len) + Ansi.RED + black_player + Ansi.RESET
@@ -366,8 +402,10 @@ class Game:
                     column_str = str(column)
                     ansi_color = Ansi.CYAN if column.color == 'white' else Ansi.RED
                     ansi_reset = Ansi.RESET
-                if [i, j] in self.highlight_cells or self.selected_cell == [i, j]:
+                if [i, j] in self.highlight_cells:
                     column_str = '*' + column_str.lstrip() + '*'
+                elif self.selected_cell == [i, j]:
+                    column_str = '<' + column_str.lstrip() + '>'
                 output += '| ' + ansi_color + column_str + ansi_reset + (' ' * (self.CELL_WIDTH-len(column_str)))
                 j += 1
             output += '|\n'
@@ -415,6 +453,7 @@ DESCRIPTION
 
 OPTIONS
     --help: shows this help
+    --help --verbose: show full help
     --version|-v: shows the version of tchess
     --no-ansi: disable terminal ansi colors
     --replay: play the saved game
@@ -428,6 +467,107 @@ AUTHOR
     And Licensed under MIT
 ''')
 
+    if '--verbose' in sys.argv:
+        print('''
+GAME
+    GET STARTED
+        Tchess can save your game in a file, then you can continue that game later. If you run the above command, game will be saved in game.tchess file in current working directory.
+
+        But you can customize the file:
+
+        $ tchess my-game.bin
+
+        Also if you played a game and closed that and now you want to continue that game, only give file name as argument:
+
+        $ tchess my-old-game.bin
+
+        (The .bin extension is a example, you can name it whatever you want).
+
+    BASICS
+
+        when you run the game, you see something like this:
+
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        | w-rock    | w-knight  | w-bishop  | w-king    | w-queen   | w-bishop  | w-knight  | w-rock    |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        |  3-1      |  3-2      |  3-3      |  3-4      |  3-5      |  3-6      |  3-7      |  3-8      |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        |  4-1      |  4-2      |  4-3      |  4-4      |  4-5      |  4-6      |  4-7      |  4-8      |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        |  5-1      |  5-2      |  5-3      |  5-4      |  5-5      |  5-6      |  5-7      |  5-8      |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        |  6-1      |  6-2      |  6-3      |  6-4      |  6-5      |  6-6      |  6-7      |  6-8      |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+        | b-rock    | b-knight  | b-bishop  | b-king    | b-queen   | b-bishop  | b-knight  | b-rock    |
+        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
+                                                                                                        
+        white Turn >>>
+
+        The above content will be showed in the terminal. and there is a command input in the bottom. You should pass commands to that for running the game.
+
+        Also there is white Turn. this means its turn of white team. if you do something, this will be changed to black Turn.
+
+        Also name of Pieces is <team>-<type>. for example b-queen (black queen) and w-king (white king).
+
+        The location of cells is accessible with this pattern: <row>-<column> or <row>.<column>. For example 1-1 or 6.4.
+        exit
+
+        command exit, exits the program:
+
+        >>> exit
+
+        Moving the pieces
+
+        For moving pieces, you should enter this command:
+
+        >>> move <src> to <dst>
+
+        for example:
+
+        >>> move 2.1 to 4.1
+
+        Also you can use mv keyword instead of move:
+
+        >>> mv a to b
+
+        Also you can don't use to keyword. for example:
+
+        >>> mv 2.1 3.1
+
+        Also you can see which pieces in the board are allowed to go to the which cells:
+
+        >>> s 2.2
+
+        The above command s <cell-address>, will show you the piece in the entered address can go to which cells (The allowed cells will be highlighted with *).
+        Back
+
+        You can revert your moves and back to the previous status.
+
+        >>> back
+
+        This is useful if you insert a wrong command or move wrong.
+        Replaying a saved game
+
+        If you played a game and it is saved, you can play that!
+
+        You should use option --replay:
+
+        $ tchess --replay my-saved-game.file
+
+        Then you can see your game is Replaying!
+
+        Also you can set frame speed of Replaying using --replay-speed option:
+
+        $ tchess --replay my-saved-game.file --replay-speed=3 # means 3 seound
+        $ tchess --replay my-saved-game.file --replay-speed=0.5
+
+        (sort of options is not important).
+'''.strip())
+
 def load_game_from_file(path: str):
     """ Loads the game object from a file """
     tmp_f = open(path, 'rb')
@@ -441,6 +581,9 @@ def load_game_from_file(path: str):
     game.white_player = str(file_game.white_player)
     game.black_player = str(file_game.black_player)
     game.board = list(file_game.board)
+    game.is_end = bool(file_game.is_end)
+    game.winner = file_game.winner
+    game.current_check = file_game.current_check
     return game
 
 def run(args=[]):
@@ -549,6 +692,20 @@ def run(args=[]):
         print(' ' * len(Game.ROW_SEPARATOR))
         print(game.render())
 
+        if game.is_end:
+            # game is finished
+            print(Ansi.GREEN + 'Checkmate!' + Ansi.RESET + (' ' * (len(Game.ROW_SEPARATOR)-10)))
+            color = Ansi.CYAN if game.winner == 'white' else Ansi.RED
+            print(color + game.winner + Ansi.GREEN + ' won!' + Ansi.RESET)
+            next_step = input('Press enter to continnue or type `back`: ').strip().lower()
+            if next_step == 'back':
+                game.is_end = False
+                game.winner = None
+                game.run_command('back')
+                continue
+            else:
+                break
+
         # get command from user and run it
         tmp_turn = game.turn
         ansi_color = Ansi.RED if tmp_turn == 'black' else Ansi.CYAN
@@ -592,9 +749,10 @@ def run(args=[]):
         # open a file
         # this file is used to save the game state
         # after any command on the game, game will be re-write on this file
-        game_file = open(game_file_name, 'wb')
-        pickle.dump(game, game_file)
-        game_file.close()
+        if not is_play:
+            game_file = open(game_file_name, 'wb')
+            pickle.dump(game, game_file)
+            game_file.close()
 
 if __name__ == '__main__':
     run(sys.argv[1:])
